import "Turbine.UI";
import "Turbine.UI.Lotro";
import "Turbine.Utils";
import "KragenPlugs.KragenBars";

-- load settings file
function LoadSettings()
	settings = Turbine.PluginData.Load( Turbine.DataScope.Character, "KragenBarsSettings" );

	-- Set main version number
	mainvars = { };
	mainvars.vers = "2.12";
	
	-- declare settings as a table and set default opacity
	if ( type( settings ) ~= "table" ) then
		settings = { };
		settings.opacity = 1;
	end
	
	-- if version is not declared then wipe settings file and set version number
	if (settings.vers == nil) then
        settings = nil;
	    settings = { };
	    settings.vers = mainvars.vers;
	    settings.opacity = 1;
	    SaveSettings();
	end
	
	-- if classbars are already setup
	if ( settings.class == "Guardian") then
		KragenBars = GuardBars();
	elseif (settings.class == "Burglar") then
	    KragenBars = BurgBars();
 	elseif (settings.class == "Champion") then
	    KragenBars = ChampBars();
	elseif (settings.class == "Captain") then
		KragenBars = CaptBars();
	elseif (settings.class == "Minstrel") then
		KragenBars = MiniBars();
	elseif (settings.class == "Runekeeper") then
		KragenBars = RuneBars();
	else
	    -- inform the user how to setup the classbar
		Turbine.Shell.WriteLine(" Welcome to KragenBars\n - To set up your class specific bars type /kragenbars <classname>");
	end

end

-- save to settings file
function SaveSettings()
	
	Turbine.PluginData.Save( Turbine.DataScope.Character, "KragenBarsSettings", settings );

end

-- on unload call each instances unload function to save settings
function UnloadPlugin()
	KragenBars:SaveSettings();
end


-- setup user chat commands
KragenBarsCommand = Turbine.ShellCommand();

function KragenBarsCommand:Execute( command, arguments )
	if (not settings.class or arguments == "guardian" or arguments == "burglar" or arguments == "captain" or arguments == "champion" or arguments == "minstrel" or arguments == "runekeeper") then
		if ( arguments == "guardian" ) then
			KragenBars = GuardBars();
			Turbine.Shell.WriteLine("KragenBars: Guardian Bars activated.  To configure settings type '/kragenbars setup'.");
		elseif ( arguments == "burglar" ) then
			KragenBars = BurgBars();
			Turbine.Shell.WriteLine("KragenBars: Burglar Bars activated.  To configure settings type '/kragenbars setup'.");
		elseif (arguments == "captain" ) then
			KragenBars = CaptBars();
			Turbine.Shell.WriteLine("KragenBars: Captain Bars activated.  To configure settings type '/kragenbars setup'.");
		elseif ( arguments == "champion" ) then
			KragenBars = ChampBars();
			Turbine.Shell.WriteLine("KragenBars: Champion Bars activated.  To configure settings type '/kragenbars setup'.");
		elseif ( arguments == "minstrel" ) then
			KragenBars = MiniBars();
			Turbine.Shell.WriteLine("KragenBars: Minstrel Bars activated.  To configure settings type '/kragenbars setup'.");
		elseif ( arguments == "runekeeper" ) then
			KragenBars = RuneBars();
			Turbine.Shell.WriteLine("KragenBars: Runekeeper Bars activated.  To configure settings type '/kragenbars setup'.");
		else
       		-- inform the user how to setup the classbar
      		Turbine.Shell.WriteLine("KragenBars: You Must set your class specific bars first\n - To set up your class specific bars type /kragenbars <classname>");
		end
	elseif (arguments == "setup") then
		KragenBars:ShowSetup();
	elseif (arguments == "refresh") then
		KragenBars:Refresh();
	elseif (arguments == "save") then
		KragenBars:SaveSettings();
	else
        Turbine.Shell.WriteLine("KragenBars Help:\n - /kragenbars setup - Opens class setup window\n - /kragenbars refresh - Refreshes class bar settings (ie. after level up)\n - /kragenbars save - Saves window positions\n - /kragenbars <classname> - Sets KragenBars to specified class default settings");
	end

end

-- inialize plugin
function init()
    settings = { };

	-- setup plugin unload function to save setting on unload.
		pluginName="KragenBars";
		window = Turbine.UI.Window();
		window:SetWantsUpdates(true);
		window.Update = function(sender,args)
			if (Plugins[pluginName] ~= nil) then
				Plugins[pluginName].Unload = function(self,sender,args)
					UnloadPlugin();
				end
				window:SetWantsUpdates(false);
			end
		end

	Turbine.Shell.AddCommand( "kragenbars", KragenBarsCommand );

	LoadSettings();
end


-- codeblock
init();